@@ -58,6 +58,7 @@ import com.openexchange.api2.RdbContactSQLImpl;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.FolderObject;
+import com.openexchange.groupware.search.Order;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionSession;
 import com.openexchange.tools.iterator.SearchIterator;
@@ -79,6 +80,8 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
 
     public int calculateSimilarityScore(Contact original, Contact candidate, Object session) throws AbstractOXException {
         int score = 0;
+        int threshhold = getThreshhold(session);
+        
         // For the sake of simplicity we assume that equal names mean equal contacts
         // TODO: This needs to be diversified in the form of "unique-in-context" later (if there is only one "Max Mustermann" in a folder it
         // is unique and qualifies as identifier. If there are two "Max Mustermann" it does not.)
@@ -104,10 +107,34 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
         if (original.containsBirthday() && candidate.containsBirthday() && eq(original.getBirthday(), candidate.getBirthday())) {
             score += 5;
         }
-
+        
+        if( score < threshhold && original.equalsContentwise(candidate)) { //the score check is only to speed the process up
+            score = threshhold + 1;
+        }
         return score;
     }
 
+    /**
+     * @param original
+     * @param candidate
+     * @return
+     */
+    private boolean hasEqualContent(Contact original, Contact candidate) {
+        for(int fieldNumber: Contact.ALL_COLUMNS){
+            if(original.get(fieldNumber) == null){
+                if(candidate.get(fieldNumber) != null){
+                    return false;
+                }
+            } else {
+                if(candidate.get(fieldNumber) != null){
+                    if(! original.get(fieldNumber).equals(candidate.get(fieldNumber)))
+                        return false;
+                }
+            }
+        }
+        return false;
+    }
+
     private boolean isset(String s) {
         return s == null || s.length() > 0;
     }
@@ -134,7 +161,7 @@ public class ContactFolderUpdaterStrategy implements FolderUpdaterStrategy<Conta
             0,
             numberOfContacts,
             Contact.OBJECT_ID,
-            "ASC",
+            Order.ASCENDING,
             COMPARISON_COLUMNS);
         List<Contact> retval = new ArrayList<Contact>();
         while (contactsInFolder.hasNext()) {
